==> benno-web-2.2.1.tgz: srv/benno/bennoweb/htdocs/tools/benno-functions.js <==
/* Tooltip */
/*
$(document).ready(function(){
setTimeout(function(){
$("[data-tooltip]").each(function(index){
var tooltipContent = $(this).data("tooltip");
var elTop = parseInt($(this).offset().top,10);
console.log(elTop);
var elLeft = parseInt($(this).offset().left,10);
$("body").append('<div id="tooltip-'+index+'" class="tooltip" style="top:'+elTop+'px;left:'+elLeft+'px"><span>' +tooltipContent+ '</span></div>');
});
}, 500);
});
*/

/* Sortierung der Nachrichten */
$('#select_nachricht').change(function(){
    document.forms.frm_select_nachricht.submit();
});

/* Anzahl der anzuzeigenden Ergebnisse */
$('#select_number').change(function(){
    document.forms.frm_select_number.submit();
});

/* Funktionen fuer die einfache Suche */
$('#submit_search_norm').click(function(event){
	event.preventDefault();
    document.forms.frm_search_norm.submit();
});
var reset_search_normf = function(){
    $('#frm_search_norm').find(':input').each(function() {
        switch(this.type) {
            case 'text':
                $(this).val('');
                break;
        }
    });
	$("select#search_min_select option[value='all']").prop('selected', true);
}
$('#reset_search_norm').click(function(event){
event.preventDefault();
reset_search_normf();
});

/* Funktionen fuer die erweiterte Suche */
$('#submit_search_ext').click(function(event){
event.preventDefault();
document.forms.frm_search_ext.submit();
});


$('#label_head_close').click(function(event){
event.preventDefault();
$(this).parent().parent().hide();
$('body').removeClass("labelVisible");
});

$('.search_load a').click(function(event){
event.preventDefault();
$('body').addClass("labelVisible");
$('#label').show();
});

// Mobile Mail Content Close
$("a#bt_close").click(function(event){
event.preventDefault();
$('body').removeClass('mobileEmailView');
$('#mailcontent').removeClass("mobileActive");
});

// Steuerung der Tabulator Funktion
var maxTabIndex = -1;
$("*[tabindex]").attr('tabindex', function (a, b) {
    maxTabIndex = Math.max(maxTabIndex, +b);	
});

$('body').on('keydown', function (e) {
    var target = $(e.target);
    if (e.keyCode == 9) {
        if ((parseInt(target.attr("tabindex"))+1) == maxTabIndex) {
           e.preventDefault();
		   $("*[tabindex=1]").eq(0).focus();
		   
    }
	}
});

// Email Button Original anzeigen
$('a#bt_original').click(function(event){
event.preventDefault();
var url = $(this).attr("href");
$('#dialog_original textarea').load(url);
});

// Email Button Permalink anzeigen
$('a#bt_permalink').click(function(event){
event.preventDefault();
var url = $(this).attr("href");
var input = $('#dialog_permalink input');
input.val(window.location.href.split('?')[0]+url);
});

// Email Weiterleitung mit Enter bestätigen
$('#wl_mailto').on('keydown', function (e) {
    if (e.keyCode == 13) {
		$("#dialog_wl_submit").click();
    }
});

// Modal Permalink Copy to Clipboard
$('a#dialog_permalink_copy').click(function(event){
event.preventDefault();
var input = $('#dialog_permalink input');
input.select();
document.execCommand("copy");
});

// Standard Suche Emails holen für Heute, Woche, Monat
$('a.search_min_button').click(function(event){
event.preventDefault();
var period = $(this).data("period");
console.log(period);
$.ajax({
    'url': '',
    'data':{ 'CA': 'a_fetchEmails',
             'time': period
           },
});
});

// Mobile Suchform schließen
$('.mobile_search_close a').click(function(event){
event.preventDefault();
$('#panel').removeClass("showPanel");
});


//$('#store_search_ext').click(function(){
//    $('#frm_search_ext_CA').val('storeQuery');
//    document.forms.frm_search_ext.submit();
//});
var reset_search_extf = function(){
  $('#frm_search_ext').find(':input').each(function() {
    switch(this.type) {
        case 'password':
        case 'select-multiple':
        case 'select-one':
        case 'text':
        case 'textarea':
            if (this.id == 'start-date') {
                $('#start-date').val('');
                break;
            }
            if (this.id == 'end-date') {
                $('#end-date').val('');
                break;
            }
            $(this).val('');
        break;
        case 'checkbox':
        case 'radio':
        this.checked = false;
    }
  });
}
$('#reset_search_ext').click(function(event){event.preventDefault(); reset_search_extf()});
$('#absender').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#betreff').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#empfaenger').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#volltext').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});

// Durch skippen der Nachrichten in der Übersicht
$(function(){
 if ( $(".min_mail").eq(0).length ) {
	 
   var entry = $(".min_mail");
   
    $('html').keydown(function(e){
		
		var getActiveEntry = $(".min_mail.active");
		
		if (e.which == 40) { // Pfeil nach unten
			  if (getActiveEntry.index() == entry.last().index()) {
				  // entry.first().find("a").click();
		      } else {
				  if (!$("#panel input").is(":focus")) {
				  e.preventDefault();
			      getActiveEntry.next().find("a").click();
				  }
			  }
			}
		if (e.which == 38) { // Pfeil nach oben
			if (getActiveEntry.index() == entry.first().index()) {
				  // entry.last().find("a").click();
		      } else {
				  if (!$("#panel input").is(":focus")) {
				  e.preventDefault();
			      getActiveEntry.prev().find("a").click();
				  }
			  }
			}
	});
 }
});

// Kontext Menü Alle Emails von Email Adresse suchen
/*
$("#EMail_From").click(function(event){
	event.preventDefault();
	if ( !$(this).children(".quickAction").length && !$(this).hasClass(".quickAction_open") ) {
	  $(this).addClass("quickAction_open");
	  $(this).append('<div class="quickAction quick_a_searchMail"><a href="#">Alle Emails von dieser Adresse suchen.</a></div>');
	}
	});

$("#EMail_From").on('click', '.quick_a_searchMail a', function (event){
	event.preventDefault();
	$(this).parent().remove();
	$(this).parent().parent().removeClass("quickAction_open");
});
*/

function on_resize(c,t){onresize=function(){clearTimeout(t);t=setTimeout(c,100)};return c};

var recalcHeightsOverview = function(){
	if ( $(window).width() >= 1350) {
	var browserHeight = $(window).height();
	var headerHeight = $("#header").outerHeight();
	var stageHeadHeight = $("#overview").find(".stage_head").outerHeight();
	var padding = 30;
	var height = browserHeight-(headerHeight+stageHeadHeight+padding);
	if (browserHeight < $("#panel").outerHeight()+headerHeight ) {height = ($("#panel").outerHeight()-(stageHeadHeight+10));}
    $('.scroll-panel1').height(height);
	} else {
	$('.scroll-panel1').css("height","auto");
	}
};
var recalcHeightsMailContent = function(){
	if ( $(window).width() >= 1350) {
	var browserHeight = $(window).height();
	var headerHeight = $("#header").outerHeight();
	var stageHeadHeight = $("#mailcontent").find(".stage_head").outerHeight();
	var padding = 30;
	var height = browserHeight-(headerHeight+stageHeadHeight+padding);
	if (browserHeight < $("#panel").outerHeight()+headerHeight ) {height = ($("#panel").outerHeight()-(stageHeadHeight+10));}
    $('.scroll-panel2').height(height);
	} else {
	if ( $(window).width() <= 600 ) { $('.scroll-panel2').css("height",$(window).height()-67); } else {$('.scroll-panel2').css("height","auto");}
	}
};
recalcHeightsMailContent();
recalcHeightsOverview();

on_resize(function() {
recalcHeightsMailContent();
recalcHeightsOverview();
});
/*
$(document).ready(function(){
$('.scroll-panel1').slimScroll({
    color: '#e7e7e7',
    size: '10px',
	opacity: 0.8,
	distance: '1px',
	height: recalcHeightsOverview()+"px",
    // height: '180px',
    alwaysVisible: true
});
$('.scroll-panel2').slimScroll({
    color: '#e7e7e7',
    size: '10px',
	opacity: 0.8,
	distance: '1px',
	height: recalcHeightsMailContent()+"px",
    // height: '180px',
    alwaysVisible: true
});
});
*/

// datePicker localization
$.dpText = {
    TEXT_PREV_YEAR      :   'Letztes Jahr',
    TEXT_PREV_MONTH     :   'Vorheriger Monat',
    TEXT_NEXT_YEAR      :   'Nächstes Jahr',
    TEXT_NEXT_MONTH     :   'Nächster Monat',
    TEXT_CLOSE          :   'Schließen',
    TEXT_CHOOSE_DATE    :   'Datum auswählen',
    HEADER_FORMAT       :   'MMMM JJJJ'
};

// Container Switch
$('#select_container').change(function(){
$.ajax({
    'url': '',
    'data':{ 'CA': 'a_switchContainer',
             'container': $('#select_container').val(),
           },
});
});

==> benno-web-2.2.7.tgz: srv/benno/bennoweb/htdocs/tools/benno-functions.js <==
/* Tooltip */
/*
$(document).ready(function(){
setTimeout(function(){
$("[data-tooltip]").each(function(index){
var tooltipContent = $(this).data("tooltip");
var elTop = parseInt($(this).offset().top,10);
console.log(elTop);
var elLeft = parseInt($(this).offset().left,10);
$("body").append('<div id="tooltip-'+index+'" class="tooltip" style="top:'+elTop+'px;left:'+elLeft+'px"><span>' +tooltipContent+ '</span></div>');
});
}, 500);
});
*/

/* Sortierung der Nachrichten */
$('#select_nachricht').change(function(){
    document.forms.frm_select_nachricht.submit();
});

/* Anzahl der anzuzeigenden Ergebnisse */
$('#select_number').change(function(){
    document.forms.frm_select_number.submit();
});

/* Funktionen fuer die einfache Suche */
$('#submit_search_norm').click(function(event){
	event.preventDefault();
    document.forms.frm_search_norm.submit();
});
var reset_search_normf = function(){
    $('#frm_search_norm').find(':input').each(function() {
        switch(this.type) {
            case 'text':
                $(this).val('');
                break;
        }
    });
	$("select#search_min_select option[value='all']").prop('selected', true);
}
$('#reset_search_norm').click(function(event){
event.preventDefault();
reset_search_normf();
});

/* Funktionen fuer die erweiterte Suche */
$('#submit_search_ext').click(function(event){
event.preventDefault();
document.forms.frm_search_ext.submit();
});


$('#label_head_close').click(function(event){
event.preventDefault();
$(this).parent().parent().hide();
$('body').removeClass("labelVisible");
});

$('.search_load a').click(function(event){
event.preventDefault();
$('body').addClass("labelVisible");
$('#label').show();
});

// Mobile Mail Content Close
$("a#bt_close").click(function(event){
event.preventDefault();
$('body').removeClass('mobileEmailView');
$('#mailcontent').removeClass("mobileActive");
});

// Steuerung der Tabulator Funktion
var maxTabIndex = -1;
$("*[tabindex]").attr('tabindex', function (a, b) {
    maxTabIndex = Math.max(maxTabIndex, +b);	
});

$('body').on('keydown', function (e) {
    var target = $(e.target);
    if (e.keyCode == 9) {
        if ((parseInt(target.attr("tabindex"))+1) == maxTabIndex) {
           e.preventDefault();
		   $("*[tabindex=1]").eq(0).focus();
		   
    }
	}
});

// Email Button Original anzeigen
$('a#bt_original').click(function(event){
event.preventDefault();
var url = $(this).attr("href");
$('#dialog_original textarea').load(url);
});

// Email Button Permalink anzeigen
$('a#bt_permalink').click(function(event){
event.preventDefault();
var url = $(this).attr("href");
var input = $('#dialog_permalink input');
input.val(window.location.href.split('?')[0]+url);
});

// Email Weiterleitung mit Enter bestätigen
$('#wl_mailto').on('keydown', function (e) {
    if (e.keyCode == 13) {
		$("#dialog_wl_submit").click();
    }
});

// Modal Permalink Copy to Clipboard
$('a#dialog_permalink_copy').click(function(event){
event.preventDefault();
var input = $('#dialog_permalink input');
input.select();
document.execCommand("copy");
});

// Standard Suche Emails holen für Heute, Woche, Monat
$('a.search_min_button').click(function(event){
event.preventDefault();
var period = $(this).data("period");
	
if ("today" == period) {
	$("#start-date").datepicker( "setDate", "d" );
	$("#end-date").datepicker( "setDate", "d" );
}
	
if ("week" == period) {
	
    var startOfWeek = moment().startOf('isoweek').toDate();
    //var endOfWeek   = moment().endOf('isoweek').toDate();
	
	$("#start-date").datepicker( "setDate", startOfWeek );
	$("#end-date").datepicker( "setDate", "d" );
}

if ("month" == period) {
	
	var startOfMonth = moment().startOf('month').toDate();
   //var endOfMonth   = moment().endOf('month').toDate();
	
	$("#start-date").datepicker( "setDate", startOfMonth );
	$("#end-date").datepicker( "setDate", "d" );
}
	
if ("quarter" == period) {
	
	var startOfQuarter = moment().startOf('quarter').toDate();
    //var endOfQuarter   = moment().endOf('quarter').toDate();
	
	$("#start-date").datepicker( "setDate", startOfQuarter );
	$("#end-date").datepicker( "setDate", "d" );
}
	
if ("year" == period) {
	
	var startOfYear = moment().startOf('year').toDate();
    //var endOfYear   = moment().endOf('quarter').toDate();
	
	$("#start-date").datepicker( "setDate", startOfYear );
	$("#end-date").datepicker( "setDate", "d" );
}
// no auto-submit: $('#frm_search_ext').submit();

});

// Mobile Suchform schließen
$('.mobile_search_close a').click(function(event){
event.preventDefault();
$('#panel').removeClass("showPanel");
});

// Attachment Datei Typ Select Box einblenden
$('#isAttachment').click(function(event){
$('#input_attachment_wrapper').toggleClass("showThis");
});



//$('#store_search_ext').click(function(){
//    $('#frm_search_ext_CA').val('storeQuery');
//    document.forms.frm_search_ext.submit();
//});
var reset_search_extf = function(){
  $('#frm_search_ext').find(':input').each(function() {
    switch(this.type) {
        case 'password':
        case 'select-multiple':
        case 'select-one':
        case 'text':
        case 'textarea':
            if (this.id == 'start-date') {
                $('#start-date').val('');
                break;
            }
            if (this.id == 'end-date') {
                $('#end-date').val('');
                break;
            }
            $(this).val('');
        break;
        case 'checkbox':
        case 'radio':
        this.checked = false;
    }
  });
}
$('#reset_search_ext').click(function(event){event.preventDefault(); reset_search_extf()});
$('#absender').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#betreff').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#empfaenger').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#volltext').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});

// Durch skippen der Nachrichten in der Übersicht
$(function(){
 if ( $(".min_mail").eq(0).length ) {
	 
   var entry = $(".min_mail");
   
    $('html').keydown(function(e){
		
		var getActiveEntry = $(".min_mail.active");
		
		if (e.which == 40) { // Pfeil nach unten
			  if (getActiveEntry.index() == entry.last().index()) {
				  // entry.first().find("a").click();
		      } else {
				  if (!$("#panel input").is(":focus")) {
				  e.preventDefault();
			      getActiveEntry.next().find("a").click();
				  }
			  }
			}
		if (e.which == 38) { // Pfeil nach oben
			if (getActiveEntry.index() == entry.first().index()) {
				  // entry.last().find("a").click();
		      } else {
				  if (!$("#panel input").is(":focus")) {
				  e.preventDefault();
			      getActiveEntry.prev().find("a").click();
				  }
			  }
			}
	});
 }
});

// Kontext Menü Alle Emails von Email Adresse suchen
/*
$("#EMail_From").click(function(event){
	event.preventDefault();
	if ( !$(this).children(".quickAction").length && !$(this).hasClass(".quickAction_open") ) {
	  $(this).addClass("quickAction_open");
	  $(this).append('<div class="quickAction quick_a_searchMail"><a href="#">Alle Emails von dieser Adresse suchen.</a></div>');
	}
	});

$("#EMail_From").on('click', '.quick_a_searchMail a', function (event){
	event.preventDefault();
	$(this).parent().remove();
	$(this).parent().parent().removeClass("quickAction_open");
});
*/

function on_resize(c,t){onresize=function(){clearTimeout(t);t=setTimeout(c,100)};return c};

var recalcHeightsOverview = function(){
	if ( $(window).width() >= 1350) {
	var browserHeight = $(window).height();
	var headerHeight = $("#header").outerHeight();
	var stageHeadHeight = $("#overview").find(".stage_head").outerHeight();
	var padding = 30;
	var height = browserHeight-(headerHeight+stageHeadHeight+padding);
	if (browserHeight < $("#panel").outerHeight()+headerHeight ) {height = ($("#panel").outerHeight()-(stageHeadHeight+10));}
    $('.scroll-panel1').height(height);
	} else {
	$('.scroll-panel1').css("height","auto");
	}
};
var recalcHeightsMailContent = function(){
	if ( $(window).width() >= 1350) {
	var browserHeight = $(window).height();
	var headerHeight = $("#header").outerHeight();
	var stageHeadHeight = $("#mailcontent").find(".stage_head").outerHeight();
	var padding = 30;
	var height = browserHeight-(headerHeight+stageHeadHeight+padding);
	if (browserHeight < $("#panel").outerHeight()+headerHeight ) {height = ($("#panel").outerHeight()-(stageHeadHeight+10));}
    $('.scroll-panel2').height(height);
	} else {
	if ( $(window).width() <= 600 ) { $('.scroll-panel2').css("height",$(window).height()-67); } else {$('.scroll-panel2').css("height","auto");}
	}
};
recalcHeightsMailContent();
recalcHeightsOverview();

on_resize(function() {
recalcHeightsMailContent();
recalcHeightsOverview();
});
/*
$(document).ready(function(){
$('.scroll-panel1').slimScroll({
    color: '#e7e7e7',
    size: '10px',
	opacity: 0.8,
	distance: '1px',
	height: recalcHeightsOverview()+"px",
    // height: '180px',
    alwaysVisible: true
});
$('.scroll-panel2').slimScroll({
    color: '#e7e7e7',
    size: '10px',
	opacity: 0.8,
	distance: '1px',
	height: recalcHeightsMailContent()+"px",
    // height: '180px',
    alwaysVisible: true
});
});
*/

// datePicker localization
$.dpText = {
    TEXT_PREV_YEAR      :   'Letztes Jahr',
    TEXT_PREV_MONTH     :   'Vorheriger Monat',
    TEXT_NEXT_YEAR      :   'Nächstes Jahr',
    TEXT_NEXT_MONTH     :   'Nächster Monat',
    TEXT_CLOSE          :   'Schließen',
    TEXT_CHOOSE_DATE    :   'Datum auswählen',
    HEADER_FORMAT       :   'MMMM JJJJ'
};

// Container Switch
$('#select_container').change(function(){
$.ajax({
    'url': '',
    'data':{ 'CA': 'a_switchContainer',
             'container': $('#select_container').val(),
           },
});
});
